@@ -1,20 +1,21 @@
-use crate::config::editor_app::EditorApp;
 use serde::{Deserialize, Serialize};
 
+use crate::config::application::Application;
+
 #[derive(Serialize, Deserialize, Debug, Clone, Default, Eq, PartialEq)]
 pub struct Editor {
-    pub app: EditorApp,
+    pub app: Application,
     pub command: String,
 }
 
 impl Editor {
-    pub fn new(app: EditorApp) -> Self {
+    pub fn new(app: Application) -> Self {
         let command = app.command();
         Editor { app, command }
     }
     pub fn custom(command: String) -> Self {
         Editor {
-            app: EditorApp::Custom,
+            app: Application::Custom,
             command,
         }
     }
