@@ -1,6 +1,6 @@
+pub mod application;
 pub mod clone;
 pub mod editor;
-pub mod editor_app;
 pub mod fork;
 pub mod host;
 pub mod project;
